@@ -1,6 +1,6 @@
 /*
 	Actionaz
-	Copyright (C) 2008-2013 Jonathan Mercier-Ganady
+	Copyright (C) 2008-2014 Jonathan Mercier-Ganady
 
 	Actionaz is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -102,7 +102,7 @@ namespace Code
             return constructor(QPixmap::grabWindow(windowId).toImage(), engine);
 		}
 
-        return constructor(ActionTools::ScreenShooter::captureScreen().toImage(), engine);
+        return constructor(ActionTools::ScreenShooter::captureAllScreens().toImage(), engine);
     }
 
     QScriptValue Image::takeScreenshotUsingScreenIndex(QScriptContext *context, QScriptEngine *engine)
