@@ -1,6 +1,6 @@
 /*
 	Actionaz
-	Copyright (C) 2008-2013 Jonathan Mercier-Ganady
+	Copyright (C) 2008-2014 Jonathan Mercier-Ganady
 
 	Actionaz is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -83,9 +83,13 @@ namespace ActionTools
         void showVariableMenuAsPopup();
         void insertVariable(QAction *action);
 
-	private:
-        QMenu *createVariablesMenu(QMenu *parentMenu);
+    protected:
+        virtual QMenu *createVariablesMenu(QMenu *parentMenu, bool ignoreMultiline = false);
+        virtual QMenu *createResourcesMenu(QMenu *parentMenu, bool ignoreMultiline = false);
+
+    private:
 		void resizeButtons();
+        void addVariablesAndResourcesMenus(QMenu *menu);
 		
 		void mouseMoveEvent(QMouseEvent *event);
 		void multilineCheck(const QString &text);
