@@ -1,6 +1,6 @@
 /*
 	Actionaz
-	Copyright (C) 2008-2013 Jonathan Mercier-Ganady
+	Copyright (C) 2008-2014 Jonathan Mercier-Ganady
 
 	Actionaz is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -49,4 +49,9 @@ namespace ActionTools
 	{
 		actionInstance->setSubParameter(name().original(), "value", mDateTimeEdit->isCode(), mDateTimeEdit->text());
 	}
+
+    void DateTimeParameterDefinition::setDefaultValues(ActionInstance *actionInstance)
+    {
+        actionInstance->setSubParameter(name().original(), "value", QDateTime::currentDateTime());
+    }
 }
