@@ -1,6 +1,6 @@
 /*
 	Actionaz
-	Copyright (C) 2008-2013 Jonathan Mercier-Ganady
+	Copyright (C) 2008-2014 Jonathan Mercier-Ganady
 
 	Actionaz is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -42,6 +42,9 @@ namespace ActionTools
 		void setCaption(const QString &caption)						{ mCaption = caption; }
 		void setFilter(const QString &filter)						{ mFilter = filter; }
 		void setDirectory(const QString &directory)					{ mDirectory = directory; }
+
+    protected:
+        FileEdit *fileEdit()                                        { return mFileEdit; }
 		
 	private:
 		FileEdit *mFileEdit;
