@@ -1,6 +1,6 @@
 /*
     Actionaz
-    Copyright (C) 2008-2013 Jonathan Mercier-Ganady
+    Copyright (C) 2008-2014 Jonathan Mercier-Ganady
 
     Actionaz is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,18 +28,20 @@ class QWidget;
 
 namespace ActionTools
 {
+    class Script;
+
     class ACTIONTOOLSSHARED_EXPORT ParameterContainer
     {
     public:
-        ParameterContainer()
-        {
-        }
+        ParameterContainer(Script *script);
 
-        virtual ~ParameterContainer()
-        {
-        }
+        virtual ~ParameterContainer();
 
         virtual QMenu *createVariablesMenu(QWidget *parent) const = 0;
+        virtual QMenu *createResourcesMenu(QWidget *parent) const;
+
+    private:
+        Script *mScript;
     };
 }
 
