@@ -1,6 +1,6 @@
 /*
 	Actionaz
-	Copyright (C) 2008-2013 Jonathan Mercier-Ganady
+	Copyright (C) 2008-2014 Jonathan Mercier-Ganady
 
 	Actionaz is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -24,22 +24,29 @@
 #include "parameterdefinition.h"
 #include "actiontools_global.h"
 
+class QComboBox;
+
 namespace ActionTools
 {
 	class PositionEdit;
 
 	class ACTIONTOOLSSHARED_EXPORT PositionParameterDefinition : public ParameterDefinition
 	{
-	Q_OBJECT
+        Q_OBJECT
+
 	public:
         PositionParameterDefinition(const Name &name, QObject *parent);
 
 		void buildEditors(Script *script, QWidget *parent);
 		void load(const ActionInstance *actionInstance);
 		void save(ActionInstance *actionInstance);
+
+    private slots:
+        void positionChosen(QPointF position);
 		
 	private:
 		PositionEdit *mPositionEdit;
+        QComboBox *mPositionUnitComboBox;
 
 		Q_DISABLE_COPY(PositionParameterDefinition)
 	};
