@@ -1,6 +1,6 @@
 /*
     Actionaz
-    Copyright (C) 2008-2013 Jonathan Mercier-Ganady
+    Copyright (C) 2008-2014 Jonathan Mercier-Ganady
 
     Actionaz is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,9 +34,12 @@ namespace ActionTools
     class ACTIONTOOLSSHARED_EXPORT ScreenShooter
     {
     public:
+        static QPixmap captureScreen(int screenIndex);
         static QList< QPair<QPixmap, QRect> > captureScreens();
         static QList< QPair<QPixmap, QRect> > captureWindows(const QList<WindowHandle> &windows);
-        static QPixmap captureScreen();
+        static QPixmap captureWindow(WindowHandle window);
+        static QPixmap captureAllScreens();
+        static QPixmap captureRect(const QRect &rect);
 
     private:
         ScreenShooter();
