@@ -1,6 +1,6 @@
 /*
 	Actionaz
-	Copyright (C) 2008-2013 Jonathan Mercier-Ganady
+	Copyright (C) 2008-2014 Jonathan Mercier-Ganady
 
 	Actionaz is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -197,6 +197,8 @@ namespace ActionTools
 #ifdef ACT_PROFILE
 		Tools::HighResolutionTimer timer("Script::write");
 #endif
+        emit scriptProcessing(0, 0, tr("Writing..."));
+
 		QXmlStreamWriter stream(device);
 		stream.setAutoFormatting(true);
 
@@ -239,24 +241,52 @@ namespace ActionTools
 
 		stream.writeStartElement("parameters");
 
+        int parameterIndex = 0;
 		foreach(const ScriptParameter &parameter, mParameters)
 		{
+            emit scriptProcessing(parameterIndex, mParameters.size() - 1, tr("Writing parameters..."));
+
 			stream.writeStartElement("parameter");
 			stream.writeAttribute("name", parameter.name());
 			stream.writeAttribute("code", QString("%1").arg(parameter.isCode()));
 			stream.writeAttribute("type", QString::number(parameter.type()));
 			stream.writeCharacters(parameter.value());
 			stream.writeEndElement();
+
+            ++parameterIndex;
 		}
 
 		stream.writeEndElement();
 
+        stream.writeStartElement("resources");
+
+        QHash<QString, Resource>::const_iterator resourceIt = mResources.constBegin();
+        int resourceIndex = 0;
+        while(resourceIt != mResources.constEnd())
+        {
+            emit scriptProcessing(resourceIndex , mResources.size() - 1, tr("Writing resources..."));
+
+            stream.writeStartElement("resource");
+            stream.writeAttribute("id", resourceIt.key());
+            stream.writeAttribute("type", QString::number(resourceIt.value().type()));
+            stream.writeCharacters(qCompress(resourceIt.value().data()).toBase64());
+            stream.writeEndElement();
+
+            ++resourceIt;
+            ++resourceIndex;
+        }
+
+        stream.writeEndElement();
+
 		stream.writeStartElement("script");
 		stream.writeAttribute("pauseBefore", QString::number(pauseBefore()));
 		stream.writeAttribute("pauseAfter", QString::number(pauseAfter()));
 
+        int actionIndex = 0;
 		foreach(ActionInstance *actionInstance, mActionInstances)
 		{
+            emit scriptProcessing(actionIndex, mActionInstances.size() - 1, tr("Writing actions..."));
+
 			stream.writeStartElement("action");
 			stream.writeAttribute("name", actionInstance->definition()->id());
 
@@ -311,6 +341,8 @@ namespace ActionTools
 			}
 
 			stream.writeEndElement();
+
+            ++actionIndex;
 		}
 
 		stream.writeEndElement();
@@ -321,75 +353,84 @@ namespace ActionTools
 		return true;
 	}
 
-	Script::ReadResult Script::read(QIODevice *device, const Tools::Version &scriptVersion)
+    Script::ReadResult Script::read(QIODevice *device, const Tools::Version &scriptVersion)
 	{
 #ifdef ACT_PROFILE
 		Tools::HighResolutionTimer timer("Script::read");
 #endif
 		mMissingActions.clear();
 
-		MessageHandler messageHandler;
+        emit scriptProcessing(0, 0, tr("Reading schema..."));
 
-		QFile schemaFile(":/script.xsd");
-		if(!schemaFile.open(QIODevice::ReadOnly))
-			return ReadInternal;
+        ReadResult result = validateSchema(device, scriptVersion);
+        if(result != ReadSuccess)
+            return result;
 
-		QXmlSchema schema;
-		schema.setMessageHandler(&messageHandler);
+        emit scriptProcessing(0, 0, tr("Listing file content..."));
 
-		{
+        //List the script content
+        device->reset();
+
+        int parameterCount = 0;
+        int resourceCount = 0;
+        int actionCount = 0;
+
+        {
 #ifdef ACT_PROFILE
-			Tools::HighResolutionTimer timer("loading schema file");
+            Tools::HighResolutionTimer timer("Listing script content");
 #endif
-			if(!schema.load(&schemaFile))
-				return ReadInternal;
-		}
 
-		{
-#ifdef ACT_PROFILE
-			Tools::HighResolutionTimer timer("validating file");
-#endif
-			QXmlSchemaValidator validator(schema);
-			if(!validator.validate(device))
-			{
-				//If we could not validate, try to read the settings value to get the version
-				device->reset();
+            QXmlStreamReader stream(device);
+            while(!stream.atEnd() && !stream.hasError())
+            {
+                stream.readNext();
 
-				QXmlStreamReader stream(device);
-				while(!stream.atEnd() && !stream.hasError())
-				{
-					stream.readNext();
+                if(stream.isStartDocument() || !stream.isStartElement())
+                    continue;
 
-					if(stream.isStartDocument())
-						continue;
+                if(stream.name() == "parameters")
+                {
+                    stream.readNext();
 
-					if(!stream.isStartElement())
-						continue;
+                    for(;!stream.isEndElement() || stream.name() != "parameters";stream.readNext())
+                    {
+                        if(!stream.isStartElement())
+                            continue;
 
-					if(stream.name() == "settings")
-					{
-						const QXmlStreamAttributes &attributes = stream.attributes();
-						mProgramName = attributes.value("program").toString();
-						mProgramVersion = Tools::Version(attributes.value("version").toString());
-						mScriptVersion = Tools::Version(attributes.value("scriptVersion").toString());
-						mOs = attributes.value("os").toString();
+                        ++parameterCount;
+                    }
+                }
+                else if(stream.name() == "resources")
+                {
+                    stream.readNext();
 
-						if(mScriptVersion > scriptVersion)
-							return ReadInvalidScriptVersion;
-					}
-				}
+                    for(;!stream.isEndElement() || stream.name() != "resources";stream.readNext())
+                    {
+                        if(!stream.isStartElement())
+                            continue;
 
-				mStatusMessage = messageHandler.statusMessage();
-				mLine = messageHandler.line();
-				mColumn = messageHandler.column();
+                        ++resourceCount;
+                    }
+                }
+                else if(stream.name() == "script")
+                {
+                    stream.readNext();
 
-				return ReadInvalidSchema;
-			}
-		}
+                    for(;!stream.isEndElement() || stream.name() != "script";stream.readNext())
+                    {
+                        if(!stream.isStartElement())
+                            continue;
+
+                        ++actionCount;
+                    }
+                }
+            }
+        }
 
 		qDeleteAll(mActionInstances);
 		mActionInstances.clear();
 		mParameters.clear();
+        mResources.clear();
 
 		device->reset();
 
@@ -397,6 +438,8 @@ namespace ActionTools
 		Tools::HighResolutionTimer timer2("Reading content");
 #endif
 
+        emit scriptProcessing(0, 0, tr("Reading content..."));
+
         QHash<ActionDefinition *, Tools::Version> updatableActionDefinitions;
 
 		QXmlStreamReader stream(device);
@@ -450,6 +493,8 @@ namespace ActionTools
 					if(!stream.isStartElement())
 						continue;
 
+                    emit scriptProcessing(mParameters.size(), parameterCount - 1, tr("Reading parameters..."));
+
 					const QXmlStreamAttributes &attributes = stream.attributes();
 					ScriptParameter scriptParameter(	attributes.value("name").toString(),
 														stream.readElementText(),
@@ -459,6 +504,26 @@ namespace ActionTools
 					mParameters.append(scriptParameter);
 				}
 			}
+            else if(stream.name() == "resources")
+            {
+                stream.readNext();
+
+                for(;!stream.isEndElement() || stream.name() != "resources";stream.readNext())
+                {
+                    if(!stream.isStartElement())
+                        continue;
+
+                    emit scriptProcessing(mResources.size(), resourceCount - 1, tr("Reading resources..."));
+
+                    const QXmlStreamAttributes &attributes = stream.attributes();
+                    QString id = attributes.value("id").toString();
+                    QString base64Data = stream.readElementText();
+                    QByteArray data = qUncompress(QByteArray::fromBase64(base64Data.toAscii()));
+                    Resource resource(data, static_cast<Resource::Type>(attributes.value("type").toString().toInt()));
+
+                    mResources.insert(id, resource);
+                }
+            }
 			else if(stream.name() == "script")
 			{
 				const QXmlStreamAttributes &attributes = stream.attributes();
@@ -497,6 +562,8 @@ namespace ActionTools
 						if(!stream.isStartElement())
 							continue;
 
+                        emit scriptProcessing(mActionInstances.size(), actionCount - 1, tr("Reading actions..."));
+
 						if(stream.name() == "exception")
 						{
 							const QXmlStreamAttributes &attributes = stream.attributes();
@@ -569,7 +636,7 @@ namespace ActionTools
 		return ReadSuccess;
 	}
 
-	bool Script::validateContent(const QString &content)
+    bool Script::validateContent(const QString &content, const Tools::Version &scriptVersion)
 	{
 		QByteArray byteArray(content.toUtf8());
 		QBuffer buffer(&byteArray);
@@ -579,7 +646,7 @@ namespace ActionTools
 
 		MessageHandler messageHandler;
 
-		QFile schemaFile(":/script.xsd");
+        QFile schemaFile(QString(":/script%1.xsd").arg(scriptVersion.toString()));
 		if(!schemaFile.open(QIODevice::ReadOnly))
 			return false;
 
@@ -646,6 +713,80 @@ namespace ActionTools
         return back;
     }
 
+    Script::ReadResult Script::validateSchema(QIODevice *device, const Tools::Version &scriptVersion, bool tryOlderVersions)
+    {
+        MessageHandler messageHandler;
+
+        QFile schemaFile(QString(":/script%1.xsd").arg(scriptVersion.toString()));
+        if(!schemaFile.open(QIODevice::ReadOnly))
+            return ReadInternal;
+
+        QXmlSchema schema;
+        schema.setMessageHandler(&messageHandler);
+
+        {
+#ifdef ACT_PROFILE
+            Tools::HighResolutionTimer timer("loading schema file");
+#endif
+            if(!schema.load(&schemaFile))
+                return ReadInternal;
+        }
+
+        {
+#ifdef ACT_PROFILE
+            Tools::HighResolutionTimer timer("validating file");
+#endif
+            QXmlSchemaValidator validator(schema);
+            if(!validator.validate(device))
+            {
+                mStatusMessage = messageHandler.statusMessage();
+                mLine = messageHandler.line();
+                mColumn = messageHandler.column();
+
+                if(!tryOlderVersions)
+                    return ReadInvalidSchema;
+
+                //If we could not validate, try to read the settings value to get the version
+                device->reset();
+
+                QXmlStreamReader stream(device);
+                while(!stream.atEnd() && !stream.hasError())
+                {
+                    stream.readNext();
+
+                    if(stream.isStartDocument())
+                        continue;
+
+                    if(!stream.isStartElement())
+                        continue;
+
+                    if(stream.name() == "settings")
+                    {
+                        const QXmlStreamAttributes &attributes = stream.attributes();
+                        mProgramName = attributes.value("program").toString();
+                        mProgramVersion = Tools::Version(attributes.value("version").toString());
+                        mScriptVersion = Tools::Version(attributes.value("scriptVersion").toString());
+                        mOs = attributes.value("os").toString();
+
+                        device->reset();
+
+                        if(mScriptVersion == scriptVersion)
+                            return ReadInvalidSchema;
+
+                        if(validateSchema(device, mScriptVersion, false) != ReadSuccess)
+                            return ReadInvalidSchema;
+
+                        return ReadSuccess;
+                    }
+                }
+
+                return ReadInvalidSchema;
+            }
+        }
+
+        return ReadSuccess;
+    }
+
     QSet<QString> Script::findVariables(ActionInstance *actionInstance, ActionInstance *excludedActionInstance) const
     {
         QSet<QString> back;
@@ -677,6 +818,7 @@ namespace ActionTools
     {
         const Parameter &parameter = actionInstance->parameter(elementDefinition->name().original());
         const SubParameterHash &subParameters = parameter.subParameters();
+        QRegExp newLineRegExp("[\n\r;]");
 
         SubParameterHash::ConstIterator it = subParameters.constBegin();
         for(;it != subParameters.constEnd();++it)
@@ -688,7 +830,7 @@ namespace ActionTools
                 //Add every variable in any parameter type that is in code mode
                 const QString &code = subParameter.value().toString();
 
-                foreach(const QString &codeLine, code.split(QRegExp("[\n\r;]"), QString::SkipEmptyParts))
+                foreach(const QString &codeLine, code.split(newLineRegExp, QString::SkipEmptyParts))
                 {
                     int position = 0;
 
@@ -723,7 +865,7 @@ namespace ActionTools
 
                 while((position = ActionInstance::VariableRegExp.indexIn(text, position)) != -1)
                 {
-                    QString foundVariableName = ActionInstance::VariableRegExp.cap(2);
+                    QString foundVariableName = ActionInstance::VariableRegExp.cap(1);
 
                     position += ActionInstance::VariableRegExp.cap(0).length();
 
