@@ -1,6 +1,6 @@
 /*
     Actionaz
-    Copyright (C) 2008-2013 Jonathan Mercier-Ganady
+    Copyright (C) 2008-2014 Jonathan Mercier-Ganady
 
     Actionaz is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include "actioninstance.h"
 
 #include <QSet>
+#include <QMenu>
 
 namespace ActionTools
 {
@@ -47,4 +48,17 @@ namespace ActionTools
         else
             setText(variable);
     }
+
+    QMenu *VariableLineEdit::createResourcesMenu(QMenu *parentMenu, bool ignoreMultiline)
+    {
+        Q_UNUSED(ignoreMultiline)
+
+        //Do not allow inserting resources here, it doen't make any sense since we cannot overwrite resources
+
+        QMenu *resourceMenu = new QMenu(tr("Cannot insert resources here"), parentMenu);
+        resourceMenu->setEnabled(false);
+        resourceMenu->setIcon(QIcon(":/images/resource.png"));
+
+        return resourceMenu;
+    }
 }
