@@ -1,6 +1,6 @@
 /*
 	Actionaz
-	Copyright (C) 2008-2013 Jonathan Mercier-Ganady
+	Copyright (C) 2008-2014 Jonathan Mercier-Ganady
 
 	Actionaz is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -58,7 +58,7 @@ namespace ActionTools
 		void setWindowTitles(const QStringList &windowTitles);
 
 	private slots:
-		void on_choose_searchEnded(const WindowHandle &handle);
+        void on_choose_searchEnded(const ActionTools::WindowHandle &handle);
 
 	private:
 		Ui::WindowEdit *ui;
