@@ -1,6 +1,6 @@
 /*
 	Actionaz
-	Copyright (C) 2008-2013 Jonathan Mercier-Ganady
+	Copyright (C) 2008-2014 Jonathan Mercier-Ganady
 
 	Actionaz is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -55,19 +55,6 @@ namespace ActionTools
 	{
 		Q_UNUSED(script)
 
-		QStringList windowTitles;
-
-		foreach(const ActionTools::WindowHandle &windowHandle, ActionTools::WindowHandle::windowList())
-		{
-			QString title = windowHandle.title();
-			if(title.isEmpty())
-				continue;
-
-			windowTitles << title;
-		}
-
-		windowTitles.sort();
-
-		mWindowEdit->setWindowTitles(windowTitles);
+        mWindowEdit->setWindowTitles(ActionTools::WindowHandle::windowTitles());
 	}
 }
