@@ -1,6 +1,6 @@
 /*
 	Actionaz
-	Copyright (C) 2008-2013 Jonathan Mercier-Ganady
+	Copyright (C) 2008-2014 Jonathan Mercier-Ganady
 
 	Actionaz is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -28,6 +28,8 @@
 #include "scriptagent.h"
 #include "actioninstance.h"
 #include "code/codetools.h"
+#include "code/image.h"
+#include "code/rawdata.h"
 #include "codeactionaz.h"
 
 #include <QDesktopWidget>
@@ -136,6 +138,14 @@ namespace LibExecuter
 		mConsoleWidget->updateClearButton();
 	}
 	
+    ActionTools::ActionInstance *Executer::currentActionInstance() const
+    {
+        if(mCurrentActionIndex < 0 || mCurrentActionIndex >= mScript->actionCount())
+            return 0;
+
+        return mScript->actionAt(mCurrentActionIndex);
+    }
+
 	void printCall(QScriptContext *context, ActionTools::ConsoleWidget::Type type)
 	{
 		QApplication::processEvents();//Call this to prevent UI freeze when calling print often
@@ -169,8 +179,8 @@ namespace LibExecuter
 
 				executer->consoleWidget()->addUserLine(message,
 													   currentActionRuntimeId,
-													   context->engine()->property("currentParameter").toString(),
-													   context->engine()->property("currentSubParameter").toString(),
+                                                       context->engine()->globalObject().property("currentParameter").toString(),
+                                                       context->engine()->globalObject().property("currentSubParameter").toString(),
 													   agent->currentLine(),
 													   agent->currentColumn(),
 													   context->backtrace(),
@@ -221,6 +231,24 @@ namespace LibExecuter
 		return engine->undefinedValue();
 	}
 
+    QScriptValue callProcedureFunction(QScriptContext *context, QScriptEngine *engine)
+    {
+        if(!Executer::isExecuterRunning())
+            return QScriptValue();
+
+        if(context->argumentCount() < 1)
+            return engine->undefinedValue();
+
+        QScriptValue calleeData = context->callee().data();
+        Executer *executer = qobject_cast<Executer *>(calleeData.toQObject());
+        ActionTools::ActionInstance *currentActionInstance = executer->currentActionInstance();
+
+        if(currentActionInstance)
+            currentActionInstance->callProcedure(context->argument(0).toString());
+
+        return engine->undefinedValue();
+    }
+
 	bool Executer::startExecution(bool onlySelection)
 	{
 		Q_ASSERT(mScriptAgent);
@@ -243,10 +271,13 @@ namespace LibExecuter
 		CodeInitializer::initialize(mScriptEngine, mScriptAgent, mActionFactory);
 		mScriptAgent->setContext(ScriptAgent::Parameters);
 		
-		QScriptValue script = mScriptEngine->newObject();
+        QScriptValue script = mScriptEngine->newObject();
 		mScriptEngine->globalObject().setProperty("Script", script, QScriptValue::ReadOnly);
         script.setProperty("nextLine", 1);
         script.setProperty("line", 1, QScriptValue::ReadOnly);
+        QScriptValue callProcedureFun = mScriptEngine->newFunction(callProcedureFunction);
+        callProcedureFun.setData(mScriptEngine->newQObject(this));
+        script.setProperty("callProcedure", callProcedureFun);
 
 		QScriptValue console = mScriptEngine->newObject();
 		mScriptEngine->globalObject().setProperty("Console", console, QScriptValue::ReadOnly);
@@ -274,6 +305,40 @@ namespace LibExecuter
 		mScript->clearProcedures();
 		mScript->clearCallStack();
 
+        const QHash<QString, ActionTools::Resource> &resources = mScript->resources();
+        foreach(const QString &key, resources.keys())
+        {
+            const ActionTools::Resource &resource = resources.value(key);
+            QScriptValue value;
+
+            switch(resource.type())
+            {
+            case ActionTools::Resource::BinaryType:
+            case ActionTools::Resource::TypeCount:
+                value = Code::RawData::constructor(resource.data(), mScriptEngine);
+                break;
+            case ActionTools::Resource::TextType:
+                value = QString::fromUtf8(resource.data(), resource.data().size());
+                break;
+            case ActionTools::Resource::ImageType:
+                {
+                    QImage image;
+
+                    if(!image.loadFromData(resource.data()))
+                    {
+                        mConsoleWidget->addResourceLine(tr("Invalid image resource"), key, ActionTools::ConsoleWidget::Error);
+
+                        return false;
+                    }
+
+                    value = Code::Image::constructor(image, mScriptEngine);
+                }
+                break;
+            }
+
+            mScriptEngine->globalObject().setProperty(key, value, QScriptValue::ReadOnly | QScriptValue::Undeletable);
+        }
+
 		for(int actionIndex = 0; actionIndex < mScript->actionCount(); ++actionIndex)
 		{
 			ActionTools::ActionInstance *actionInstance = mScript->actionAt(actionIndex);
@@ -584,12 +649,7 @@ namespace LibExecuter
 
 		if(shouldStopExecution)
 		{
-			QString currentFile = mScriptAgent->currentFile();
-			QString finalMessage;
-			if(currentFile.isEmpty())
-				finalMessage = tr("Script line %1: ").arg(mCurrentActionIndex+1);
-			else
-				finalMessage = tr("Script %1, line %2: ").arg(currentFile).arg(mCurrentActionIndex+1);
+            QString finalMessage = tr("Script line %1: ").arg(mCurrentActionIndex+1);
 
 			ActionTools::ActionInstance *currentAction = mScript->actionAt(mCurrentActionIndex);
 			qint64 currentActionRuntimeId = -1;
@@ -598,8 +658,8 @@ namespace LibExecuter
 
 			mConsoleWidget->addActionLine(finalMessage + message,
 										currentActionRuntimeId,
-										mScriptEngine->property("currentParameter").toString(),
-										mScriptEngine->property("currentSubParameter").toString(),
+                                        mScriptEngine->globalObject().property("currentParameter").toString(),
+                                        mScriptEngine->globalObject().property("currentSubParameter").toString(),
 										mScriptAgent->currentLine(),
 										mScriptAgent->currentColumn(),
 										exceptionType);
@@ -842,8 +902,8 @@ namespace LibExecuter
 
 		consoleWidget()->addUserLine(text,
 									   currentActionRuntimeId,
-									   mScriptEngine->currentContext()->engine()->property("currentParameter").toString(),
-									   mScriptEngine->currentContext()->engine()->property("currentSubParameter").toString(),
+                                       mScriptEngine->globalObject().property("currentParameter").toString(),
+                                       mScriptEngine->globalObject().property("currentSubParameter").toString(),
 									   mScriptAgent->currentLine(),
 									   mScriptAgent->currentColumn(),
 									   mScriptEngine->currentContext()->backtrace(),
@@ -892,14 +952,6 @@ namespace LibExecuter
 
 		mExecutionWindow->setPauseStatus(mExecutionPaused);
 	}
-	
-	ActionTools::ActionInstance *Executer::currentActionInstance() const
-	{
-		if(mCurrentActionIndex < 0 || mCurrentActionIndex >= mScript->actionCount())
-			return 0;
-		
-		return mScript->actionAt(mCurrentActionIndex);
-	}
 
 	Executer::ExecuteActionResult Executer::canExecuteAction(int index) const
 	{
