@@ -1,6 +1,6 @@
 /*
 	Actionaz
-	Copyright (C) 2008-2013 Jonathan Mercier-Ganady
+	Copyright (C) 2008-2014 Jonathan Mercier-Ganady
 
 	Actionaz is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -47,6 +47,7 @@
 
 ActionDialog::ActionDialog(QAbstractItemModel *completionModel, ActionTools::Script *script, ActionTools::ActionDefinition *actionDefinition, const QString &localeName, QWidget *parent)
 	: QDialog(parent),
+      ParameterContainer(script),
 	  ui(new Ui::ActionDialog),
 	  mActionInstance(0),
 	  mScript(script),
@@ -67,6 +68,8 @@ ActionDialog::ActionDialog(QAbstractItemModel *completionModel, ActionTools::Scr
 #endif
 	ui->setupUi(this);
 
+    ui->buttonBox->button(QDialogButtonBox::Ok)->setDefault(true);
+
 	//Init of texts & images
 	ui->actionIcon->setPixmap(actionDefinition->icon());
 	ui->actionName->setText("<h2>" + actionDefinition->name() + "</h2>");
@@ -514,6 +517,7 @@ void ActionDialog::addParameter(ActionTools::ParameterDefinition *parameter, int
 
 	QBoxLayout *layout = new QBoxLayout(parameter->editorsOrientation() == Qt::Horizontal ? QBoxLayout::LeftToRight : QBoxLayout::TopToBottom );
 	layout->setMargin(0);
+    layout->setSpacing(1);
 
 	QWidget *parentWidget = new QWidget(this);
 	parentWidget->setLayout(layout);
