@@ -461,9 +461,8 @@
         <translation>Position du déplacement</translation>
     </message>
     <message>
-        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="68"/>
         <source>The position to move the window</source>
-        <translation>La position où déplacer la fenêtre</translation>
+        <translation type="obsolete">La position où déplacer la fenêtre</translation>
     </message>
     <message>
         <source>Resize</source>
@@ -474,6 +473,11 @@
         <source>The action to perform</source>
         <translation>L&apos;action à effectuer</translation>
     </message>
+    <message>
+        <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="68"/>
+        <source>The position where to move the window</source>
+        <translation>La position où déplacer la fenêtre</translation>
+    </message>
     <message>
         <location filename="../actions/actionpackwindows/actions/windowdefinition.h" line="77"/>
         <source>Resize width</source>
