@@ -69,72 +69,76 @@
 <context>
     <name>LibExecuter::Executer</name>
     <message>
-        <location filename="../executer/executer.cpp" line="297"/>
+        <location filename="../executer/executer.cpp" line="329"/>
+        <source>Invalid image resource</source>
+        <translation>Ressource d&apos;image invalide</translation>
+    </message>
+    <message>
+        <location filename="../executer/executer.cpp" line="362"/>
         <source>Invalid Begin procedure action, you have to end the previous procedure before starting another one</source>
         <translation>Début de procédure incorrect, vous devez d&apos;abord terminer la procédure précédente avant d&apos;en débuter une autre</translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="309"/>
+        <location filename="../executer/executer.cpp" line="374"/>
         <source>A procedure name cannot be empty</source>
         <translation>Le nom d&apos;une procédure ne peut être vide</translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="316"/>
+        <location filename="../executer/executer.cpp" line="381"/>
         <source>A procedure with the name &quot;%1&quot; has already been declared</source>
         <translation>Une procédure nommée &quot;%1&quot; existe déjà</translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="327"/>
+        <location filename="../executer/executer.cpp" line="392"/>
         <source>Invalid End procedure</source>
         <translation>Fin de procédure incorrecte</translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="349"/>
+        <location filename="../executer/executer.cpp" line="414"/>
         <source>Begin procedure action without end procedure</source>
         <translation>Début de procédure sans fin de procédure</translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="363"/>
+        <location filename="../executer/executer.cpp" line="428"/>
         <source>Incorrect parameter name: &quot;%1&quot;</source>
         <translation>Nom de paramètre incorrect : &quot;%1&quot;</translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="378"/>
+        <location filename="../executer/executer.cpp" line="443"/>
         <source>Error while evaluating parameter &quot;%1&quot;, error message: &quot;%2&quot;</source>
         <translation>Erreur lors de l&apos;évaluation du paramètre &quot;%1&quot;, message d&apos;erreur : &quot;%2&quot;</translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="535"/>
+        <location filename="../executer/executer.cpp" line="600"/>
         <source>Action design error: Invalid exception emitted (%1, line %2)</source>
         <translation>Erreur de conception de l&apos;action : Exception invalide émise (%1, ligne %2)</translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="564"/>
+        <location filename="../executer/executer.cpp" line="629"/>
         <source>Invalid exception line: %1</source>
         <translation>Ligne d&apos;exception invalide : %1</translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="590"/>
+        <location filename="../executer/executer.cpp" line="652"/>
         <source>Script line %1: </source>
         <translation>Ligne de script %1 : </translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="592"/>
         <source>Script %1, line %2: </source>
-        <translation>Script %1, ligne %2 : </translation>
+        <translation type="obsolete">Script %1, ligne %2 : </translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="657"/>
+        <location filename="../executer/executer.cpp" line="717"/>
         <source>Unable to find the label named &quot;%1&quot;</source>
         <translation>Impossible de trouver le label nommé &quot;%1&quot;</translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="671"/>
+        <location filename="../executer/executer.cpp" line="731"/>
         <source>Incorrect Script.nextLine value: %1</source>
         <translation>Valeur de Script.nextLine incorrecte : %1</translation>
     </message>
     <message>
-        <location filename="../executer/executer.cpp" line="674"/>
+        <location filename="../executer/executer.cpp" line="734"/>
         <source>The action at line %1 is invalid</source>
         <translation>L&apos;action à la ligne %1 est invalide</translation>
     </message>
